{# DO NOT REMOVE THIS FILE This file is normally inherited from the version defined by our docs theme (Furo). However, that file includes in-line styling which isn't allowed by our website's Content Security Policy (CSP). To resolve this issue, we've copied over the styling changes to `docs/source/_static/css/dark_light_mode.css`. Although this file is empty, it overwrites the template inherited from Furo. #}